#################
Production Module
#################

The *Production Module* provides the fundamental concepts required for managing
production.
This includes definition for bill of material and production orders.

.. toctree::
   :maxdepth: 2

   design
   releases
